@@ -1,6 +1,5 @@
 //! UnixListener module
-use std::future::Future;
-use std::io;
+use std::io::{Error as IoError, Result as IoResult};
 use std::path::Path;
 use std::pin::Pin;
 use std::task::{Context, Poll};
@@ -34,7 +33,7 @@ impl UnixListener {
     /// The runtime is usually set implicitly when this function is called
     /// from a future driven by a tokio runtime.
     #[inline]
-    pub fn try_bind(path: impl AsRef<Path>) -> io::Result<UnixListener> {
+    pub fn try_bind(path: impl AsRef<Path>) -> IoResult<UnixListener> {
         Ok(UnixListener {
             incoming: tokio::net::UnixListener::bind(path)?,
         })
@@ -46,7 +45,7 @@ impl Listener for UnixListener {}
 #[cfg(unix)]
 impl Accept for UnixListener {
     type Conn = UnixStream;
-    type Error = io::Error;
+    type Error = IoError;
 
     fn poll_accept(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Self::Conn, Self::Error>>> {
         match self.incoming.poll_accept(cx) {
@@ -58,13 +57,6 @@ impl Accept for UnixListener {
         }
     }
 }
-impl Future for UnixListener {
-    type Output = Option<Result<UnixStream, io::Error>>;
-
-    fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
-        self.poll_accept(cx)
-    }
-}
 
 /// UnixStream
 pub struct UnixStream {
@@ -87,42 +79,50 @@ impl UnixStream {
 }
 
 impl AsyncRead for UnixStream {
-    fn poll_read(self: Pin<&mut Self>, cx: &mut Context, buf: &mut ReadBuf) -> Poll<io::Result<()>> {
+    fn poll_read(self: Pin<&mut Self>, cx: &mut Context, buf: &mut ReadBuf) -> Poll<IoResult<()>> {
         Pin::new(&mut self.get_mut().inner_stream).poll_read(cx, buf)
     }
 }
 
 impl AsyncWrite for UnixStream {
-    fn poll_write(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &[u8]) -> Poll<io::Result<usize>> {
+    fn poll_write(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &[u8]) -> Poll<IoResult<usize>> {
         Pin::new(&mut self.get_mut().inner_stream).poll_write(cx, buf)
     }
 
-    fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<io::Result<()>> {
+    fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<IoResult<()>> {
         Pin::new(&mut self.get_mut().inner_stream).poll_flush(cx)
     }
 
-    fn poll_shutdown(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<io::Result<()>> {
+    fn poll_shutdown(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<IoResult<()>> {
         Pin::new(&mut self.get_mut().inner_stream).poll_shutdown(cx)
     }
 }
 
 #[cfg(test)]
 mod tests {
+    use futures_util::{Stream, StreamExt};
     use tokio::io::{AsyncReadExt, AsyncWriteExt};
 
-    use crate::prelude::*;
+    use super::*;
 
+    impl Stream for UnixListener {
+        type Item = Result<UnixStream, IoError>;
+
+        fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
+            self.poll_accept(cx)
+        }
+    }
     #[tokio::test]
     async fn test_unix_listener() {
         let sock_file = "/tmp/test-salvo.sock";
-        let listener = UnixListener::bind(sock_file);
+        let mut listener = UnixListener::bind(sock_file);
 
         tokio::spawn(async move {
             let mut stream = tokio::net::UnixStream::connect(sock_file).await.unwrap();
             stream.write_i32(518).await.unwrap();
         });
 
-        let mut stream = listener.await.unwrap().unwrap();
+        let mut stream = listener.next().await.unwrap().unwrap();
         assert_eq!(stream.read_i32().await.unwrap(), 518);
         std::fs::remove_file(sock_file).unwrap();
     }
