@@ -1,4 +1,4 @@
-use std::fmt;
+use std::fmt::{self, Formatter};
 use std::sync::Arc;
 
 use super::filter;
@@ -231,8 +231,8 @@ static SYMBOL_TEE: &str = "├";
 static SYMBOL_ELL: &str = "└";
 static SYMBOL_RIGHT: &str = "─";
 impl fmt::Debug for Router {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        fn print(f: &mut fmt::Formatter, prefix: &str, last: bool, router: &Router) -> fmt::Result {
+    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
+        fn print(f: &mut Formatter, prefix: &str, last: bool, router: &Router) -> fmt::Result {
             let mut path = "".to_owned();
             let mut others = Vec::with_capacity(router.filters.len());
             if router.filters.is_empty() {
@@ -240,10 +240,13 @@ impl fmt::Debug for Router {
             } else {
                 for filter in &router.filters {
                     let info = format!("{:?}", filter);
-                    if info.starts_with('[') && info.ends_with(']') && info.len() > 2 {
-                        others.push(info[1..info.len() - 1].to_owned());
-                    } else if path.is_empty() {
-                        path = info;
+                    if info.starts_with("path:") {
+                        path = info.split_once(':').unwrap().1.to_owned();
+                    } else {
+                        let mut parts = info.splitn(2, ':').collect::<Vec<_>>();
+                        if !parts.is_empty() {
+                            others.push(parts.pop().unwrap().to_owned());
+                        }
                     }
                 }
             }
@@ -532,4 +535,39 @@ mod tests {
         let matched = router.detect(&mut req, &mut path_state);
         assert!(matched.is_some());
     }
+    #[test]
+    fn test_router_detect11() {
+        let router =
+            Router::new().push(Router::with_path(r"avatars/<width:/\d+/>x<height:/\d+/>.<ext>").handle(fake_handler));
+        let mut req: Request = hyper::Request::builder()
+            .uri("http://local.host/avatars/321x641f.webp")
+            .body(hyper::Body::empty())
+            .unwrap()
+            .into();
+        let mut path_state = PathState::new(req.uri().path());
+        let matched = router.detect(&mut req, &mut path_state);
+        assert!(matched.is_none());
+
+        let mut req: Request = hyper::Request::builder()
+            .uri("http://local.host/avatars/320x640.webp")
+            .body(hyper::Body::empty())
+            .unwrap()
+            .into();
+        let mut path_state = PathState::new(req.uri().path());
+        let matched = router.detect(&mut req, &mut path_state);
+        assert!(matched.is_some());
+    }
+    #[test]
+    fn test_router_detect12() {
+        let router = Router::new().push(Router::with_path("/.well-known/acme-challenge/<token>").handle(fake_handler));
+
+        let mut req: Request = hyper::Request::builder()
+            .uri("http://local.host/.well-known/acme-challenge/q1XXrxIx79uXNl3I")
+            .body(hyper::Body::empty())
+            .unwrap()
+            .into();
+        let mut path_state = PathState::new(req.uri().path());
+        let matched = router.detect(&mut req, &mut path_state);
+        assert!(matched.is_some());
+    }
 }
